#ifndef __I18N_H__
#define __I18N_H__

#include <gtk/gtk.h>
#include <stdlib.h> /* for getenv() */
#include <iconv.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define IS_ASCII_CHAR(c) (!(((unsigned char)(c)) & 0x80))

#define IS_UTF8_FIRST_CHAR(c) ((((unsigned char)(c)) >> 6) == 0x03)
#define IS_UTF8_NON_FIRST_CHAR(c) ((((unsigned char)(c)) >> 6) == 0x02)
#define IS_UTF8_2BYTE_FIRST_CHAR(c) ((((unsigned char)(c)) >> 5) == 0x06)
#define IS_UTF8_3BYTE_FIRST_CHAR(c) ((((unsigned char)(c)) >> 4) == 0x0E)
#define IS_UTF8_4BYTE_FIRST_CHAR(c) ((((unsigned char)(c)) >> 3) == 0x1E)

#define IS_HANKANA_CHAR(c) \
   (((unsigned char)(c))>=0xa1 && ((unsigned char)(c))<=0xdf)

#define IS_EUC_CHAR(c) \
((((unsigned char)(c))>=0xa0 && ((unsigned char)(c))<=0xfe) \
   || ((unsigned char)(c) == 0x8E)) //half width katakana

#define IS_SJIS_CHAR1(c) \
   ((((unsigned char)(c))>=0x81 && ((unsigned char)(c))<=0x9f) \
    || (((unsigned char)(c))>=0xe0 && ((unsigned char)(c))<=0xef))
#define IS_SJIS_CHAR2(c) \
   (((unsigned char)(c))>=0x40 && ((unsigned char)(c))<=0xfc)

#define DILLO_CHARSET "UTF-8"
#define D_CHAR_GROWTH 3
#define LOCALE_CHARSET (a_I18n_get_DW_charset())
#define DW_CHARSET LOCALE_CHARSET
#ifndef DISABLE_ANTI_ALIAS
 #define RENDER_CHARSET "UTF-8"
#else
 #define RENDER_CHARSET DW_CHARSET
#endif

void   a_I18n_detect_DW_locale();
const gchar *a_I18n_get_DW_charset();
gboolean a_I18n_has_latin1_charset(gchar *lang);
gboolean a_I18n_use_CJK_charset(gchar *lang);
gchar *a_I18n_get_lang_from_charset(const gchar *charset);
gchar *a_I18n_fix_charset(gchar *charset);
gchar *a_I18n_get_charset_from_meta_tag(const gchar *buf, gint bufsize);
gchar *a_I18n_get_encoding(const gchar *buf, gint bufsize);
size_t a_I18n_iconv(iconv_t cd,
      char **inbuf, size_t *inbytesleft,
      char **outbuf, size_t *outbytesleft);
gchar *a_I18n_convert_raw(iconv_t *it, const gchar* buf, size_t bufsize);
gchar *a_I18n_convert(const gchar* from, const gchar* to, const gchar* buf, gint bufsize);
gint a_I18n_mblen(gchar *str);
gchar *a_I18n_string_check(const gchar *input, const gchar *charset);
gchar *a_I18n_DW_CHARSET_from_DILLO_CHARSET(const gchar* buf, gint bufsize);
gchar *a_I18n_DW_CHARSET_to_DILLO_CHARSET(const gchar* buf, gint bufsize);
gchar *a_I18n_locale_to_DILLO_CHARSET(const gchar* buf);
#define a_I18n_locale_from_DILLO_CHARSET \
        a_I18n_DW_CHARSET_from_DILLO_CHARSET

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __I18N_H__ */

/* vim: set ts=3 sw=3 sts=3 expandtab:*/
